@@ -1,6 +1,5 @@
 package cmd
 
-var leadingContentPreProcessing = true
 var unwrapScalar = true
 
 var writeInplace = false
@@ -8,12 +7,6 @@ var outputToJSON = false
 var outputFormat = "yaml"
 var inputFormat = "yaml"
 
-var xmlAttributePrefix = "+"
-var xmlContentName = "+content"
-var xmlStrictMode = false
-var xmlKeepNamespace = true
-var xmlUseRawToken = true
-
 var exitStatus = false
 var forceColor = false
 var forceNoColor = false
