@@ -5,6 +5,30 @@ import (
 )
 
 var loadScenarios = []expressionScenario{
+	{
+		skipDoc:     true,
+		description: "Load empty file with a comment",
+		expression:  `load("../../examples/empty.yaml")`,
+		expected: []string{
+			"D0, P[], (doc)::# comment\n\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Load empty file with no comment",
+		expression:  `load("../../examples/empty-no-comment.yaml")`,
+		expected: []string{
+			"D0, P[], (!!null)::\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Load multiple documents",
+		expression:  `load("../../examples/multiple_docs_small.yaml")`,
+		expected: []string{
+			"D0, P[], ()::- a: Easy! as one two three\n- another:\n    document: here\n- - 1\n  - 2\n",
+		},
+	},
 	{
 		description: "Simple example",
 		document:    `{myFile: "../../examples/thing.yml"}`,
@@ -65,6 +89,14 @@ var loadScenarios = []expressionScenario{
 			"D0, P[], (!!map)::this:\n    is: a properties file\n    cool: ay\n",
 		},
 	},
+	{
+		description: "Load from base64 encoded file",
+		document:    "cool: things",
+		expression:  `.more_stuff = load_base64("../../examples/base64.txt")`,
+		expected: []string{
+			"D0, P[], (doc)::cool: things\nmore_stuff: my secret chilli recipe is....\n",
+		},
+	},
 }
 
 func TestLoadScenarios(t *testing.T) {
