@@ -523,6 +523,35 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: !horse {cat: meow, dog: woof}\nb: !goat {dog: woof}\n",
 		},
 	},
+	{
+		description:    "Custom types: clobber tags",
+		subdescription: "Use the `c` option to clobber custom tags. Note that the second tag is now used",
+		document:       "a: !horse {cat: meow}\nb: !goat {dog: woof}",
+		expression:     ".a *=c .b",
+		expected: []string{
+			"D0, P[], (doc)::a: !goat {cat: meow, dog: woof}\nb: !goat {dog: woof}\n",
+		},
+	},
+	{
+		skipDoc:        true,
+		description:    "Custom types: clobber tags - *=",
+		subdescription: "Use the `c` option to clobber custom tags - on both the `=` and `*` operator. Note that the second tag is now used",
+		document:       "a: !horse {cat: meow}\nb: !goat {dog: woof}",
+		expression:     ".a =c .a *c .b",
+		expected: []string{
+			"D0, P[], (doc)::a: !goat {cat: meow, dog: woof}\nb: !goat {dog: woof}\n",
+		},
+	},
+	{
+		skipDoc:        true,
+		description:    "Custom types: dont clobber tags - *=",
+		subdescription: "Use the `c` option to clobber custom tags - on both the `=` and `*` operator. Note that the second tag is now used",
+		document:       "a: !horse {cat: meow}\nb: !goat {dog: woof}",
+		expression:     ".a *= .b",
+		expected: []string{
+			"D0, P[], (doc)::a: !horse {cat: meow, dog: woof}\nb: !goat {dog: woof}\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "Custom types: that are really maps",
@@ -532,6 +561,24 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: {cat: !horse 5}\nb: {cat: 5}\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "Relative merge, new fields only",
+		document:    "a: {a: original}\n",
+		expression:  `.a *=n load("../../examples/thing.yml")`,
+		expected: []string{
+			"D0, P[], (doc)::a: {a: original, b: cool.}\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Relative merge",
+		document:    "a: {a: original}\n",
+		expression:  `.a *= load("../../examples/thing.yml")`,
+		expected: []string{
+			"D0, P[], (doc)::a: {a: apple is included, b: cool.}\n",
+		},
+	},
 }
 
 func TestMultiplyOperatorScenarios(t *testing.T) {
