@@ -8,9 +8,51 @@ import (
 	"github.com/mikefarah/yq/v4/test"
 )
 
-var samplePropertiesYaml = `# block comments don't come through
+const propertiesWithCommentsOnMap = `this.thing = hi hi
+# important notes
+# about this value
+this.value = cool
+`
+
+const expectedPropertiesWithCommentsOnMapProps = `this.thing = hi hi
+
+# important notes
+# about this value
+this.value = cool
+`
+
+const expectedPropertiesWithCommentsOnMapYaml = `this:
+  thing: hi hi
+  # important notes
+  # about this value
+  value: cool
+`
+
+const propertiesWithCommentInArray = `
+this.array.0 = cat
+# important notes
+# about dogs
+this.array.1 = dog
+`
+
+const expectedPropertiesWithCommentInArrayProps = `this.array.0 = cat
+
+# important notes
+# about dogs
+this.array.1 = dog
+`
+
+const expectedPropertiesWithCommentInArrayYaml = `this:
+  array:
+    - cat
+    # important notes
+    # about dogs
+    - dog
+`
+
+const samplePropertiesYaml = `# block comments come through
 person: # neither do comments on maps
-    name: Mike # comments on values appear
+    name: Mike Wazowski # comments on values appear
     pets: 
     - cat # comments on array values appear
     food: [pizza] # comments on arrays do not
@@ -18,37 +60,52 @@ emptyArray: []
 emptyMap: []
 `
 
-var expectedProperties = `# comments on values appear
-person.name = Mike
+const expectedPropertiesUnwrapped = `# block comments come through
+# comments on values appear
+person.name = Mike Wazowski
 
 # comments on array values appear
 person.pets.0 = cat
 person.food.0 = pizza
 `
 
-var expectedUpdatedProperties = `# comments on values appear
-person.name = Mike
+const expectedPropertiesWrapped = `# block comments come through
+# comments on values appear
+person.name = "Mike Wazowski"
+
+# comments on array values appear
+person.pets.0 = cat
+person.food.0 = pizza
+`
+
+const expectedUpdatedProperties = `# block comments come through
+# comments on values appear
+person.name = Mike Wazowski
 
 # comments on array values appear
 person.pets.0 = dog
 person.food.0 = pizza
 `
 
-var expectedDecodedYaml = `person:
-  name: Mike # comments on values appear
+const expectedDecodedYaml = `person:
+  # block comments come through
+  # comments on values appear
+  name: Mike Wazowski
   pets:
-    - cat # comments on array values appear
+    # comments on array values appear
+    - cat
   food:
     - pizza
 `
 
-var expectedPropertiesNoComments = `person.name = Mike
+const expectedPropertiesNoComments = `person.name = Mike Wazowski
 person.pets.0 = cat
 person.food.0 = pizza
 `
 
-var expectedPropertiesWithEmptyMapsAndArrays = `# comments on values appear
-person.name = Mike
+const expectedPropertiesWithEmptyMapsAndArrays = `# block comments come through
+# comments on values appear
+person.name = Mike Wazowski
 
 # comments on array values appear
 person.pets.0 = cat
@@ -62,7 +119,14 @@ var propertyScenarios = []formatScenario{
 		description:    "Encode properties",
 		subdescription: "Note that empty arrays and maps are not encoded by default.",
 		input:          samplePropertiesYaml,
-		expected:       expectedProperties,
+		expected:       expectedPropertiesUnwrapped,
+	},
+	{
+		description:    "Encode properties: scalar encapsulation",
+		subdescription: "Note that string values with blank characters in them are encapsulated with double quotes",
+		input:          samplePropertiesYaml,
+		expected:       expectedPropertiesWrapped,
+		scenarioType:   "encode-wrapped",
 	},
 	{
 		description: "Encode properties: no comments",
@@ -79,7 +143,7 @@ var propertyScenarios = []formatScenario{
 	},
 	{
 		description:  "Decode properties",
-		input:        expectedProperties,
+		input:        expectedPropertiesUnwrapped,
 		expected:     expectedDecodedYaml,
 		scenarioType: "decode",
 	},
@@ -92,11 +156,39 @@ var propertyScenarios = []formatScenario{
 	},
 	{
 		description:  "Roundtrip",
-		input:        expectedProperties,
+		input:        expectedPropertiesUnwrapped,
 		expression:   `.person.pets.0 = "dog"`,
 		expected:     expectedUpdatedProperties,
 		scenarioType: "roundtrip",
 	},
+	{
+		skipDoc:      true,
+		description:  "comments on arrays roundtrip",
+		input:        propertiesWithCommentInArray,
+		expected:     expectedPropertiesWithCommentInArrayProps,
+		scenarioType: "roundtrip",
+	},
+	{
+		skipDoc:      true,
+		description:  "comments on arrays decode",
+		input:        propertiesWithCommentInArray,
+		expected:     expectedPropertiesWithCommentInArrayYaml,
+		scenarioType: "decode",
+	},
+	{
+		skipDoc:      true,
+		description:  "comments on map roundtrip",
+		input:        propertiesWithCommentsOnMap,
+		expected:     expectedPropertiesWithCommentsOnMapProps,
+		scenarioType: "roundtrip",
+	},
+	{
+		skipDoc:      true,
+		description:  "comments on map decode",
+		input:        propertiesWithCommentsOnMap,
+		expected:     expectedPropertiesWithCommentsOnMapYaml,
+		scenarioType: "decode",
+	},
 	{
 		description:  "Empty doc",
 		skipDoc:      true,
@@ -106,7 +198,7 @@ var propertyScenarios = []formatScenario{
 	},
 }
 
-func documentEncodePropertyScenario(w *bufio.Writer, s formatScenario) {
+func documentUnwrappedEncodePropertyScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, fmt.Sprintf("## %v\n", s.description))
 
 	if s.subdescription != "" {
@@ -128,7 +220,32 @@ func documentEncodePropertyScenario(w *bufio.Writer, s formatScenario) {
 	}
 	writeOrPanic(w, "will output\n")
 
-	writeOrPanic(w, fmt.Sprintf("```properties\n%v```\n\n", processFormatScenario(s, NewYamlDecoder(), NewPropertiesEncoder())))
+	writeOrPanic(w, fmt.Sprintf("```properties\n%v```\n\n", processFormatScenario(s, NewYamlDecoder(ConfiguredYamlPreferences), NewPropertiesEncoder(true))))
+}
+
+func documentWrappedEncodePropertyScenario(w *bufio.Writer, s formatScenario) {
+	writeOrPanic(w, fmt.Sprintf("## %v\n", s.description))
+
+	if s.subdescription != "" {
+		writeOrPanic(w, s.subdescription)
+		writeOrPanic(w, "\n\n")
+	}
+
+	writeOrPanic(w, "Given a sample.yml file of:\n")
+	writeOrPanic(w, fmt.Sprintf("```yaml\n%v\n```\n", s.input))
+
+	writeOrPanic(w, "then\n")
+
+	expression := s.expression
+
+	if expression != "" {
+		writeOrPanic(w, fmt.Sprintf("```bash\nyq -o=props --unwrapScalar=false '%v' sample.yml\n```\n", expression))
+	} else {
+		writeOrPanic(w, "```bash\nyq -o=props --unwrapScalar=false sample.yml\n```\n")
+	}
+	writeOrPanic(w, "will output\n")
+
+	writeOrPanic(w, fmt.Sprintf("```properties\n%v```\n\n", processFormatScenario(s, NewYamlDecoder(ConfiguredYamlPreferences), NewPropertiesEncoder(false))))
 }
 
 func documentDecodePropertyScenario(w *bufio.Writer, s formatScenario) {
@@ -153,7 +270,7 @@ func documentDecodePropertyScenario(w *bufio.Writer, s formatScenario) {
 
 	writeOrPanic(w, "will output\n")
 
-	writeOrPanic(w, fmt.Sprintf("```yaml\n%v```\n\n", processFormatScenario(s, NewPropertiesDecoder(), NewYamlEncoder(s.indent, false, true, true))))
+	writeOrPanic(w, fmt.Sprintf("```yaml\n%v```\n\n", processFormatScenario(s, NewPropertiesDecoder(), NewYamlEncoder(s.indent, false, ConfiguredYamlPreferences))))
 }
 
 func documentRoundTripPropertyScenario(w *bufio.Writer, s formatScenario) {
@@ -178,7 +295,7 @@ func documentRoundTripPropertyScenario(w *bufio.Writer, s formatScenario) {
 
 	writeOrPanic(w, "will output\n")
 
-	writeOrPanic(w, fmt.Sprintf("```properties\n%v```\n\n", processFormatScenario(s, NewPropertiesDecoder(), NewPropertiesEncoder())))
+	writeOrPanic(w, fmt.Sprintf("```properties\n%v```\n\n", processFormatScenario(s, NewPropertiesDecoder(), NewPropertiesEncoder(true))))
 }
 
 func documentPropertyScenario(t *testing.T, w *bufio.Writer, i interface{}) {
@@ -186,24 +303,35 @@ func documentPropertyScenario(t *testing.T, w *bufio.Writer, i interface{}) {
 	if s.skipDoc {
 		return
 	}
-	if s.scenarioType == "decode" {
+	switch s.scenarioType {
+	case "":
+		documentUnwrappedEncodePropertyScenario(w, s)
+	case "decode":
 		documentDecodePropertyScenario(w, s)
-	} else if s.scenarioType == "roundtrip" {
+	case "encode-wrapped":
+		documentWrappedEncodePropertyScenario(w, s)
+	case "roundtrip":
 		documentRoundTripPropertyScenario(w, s)
-	} else {
-		documentEncodePropertyScenario(w, s)
-	}
 
+	default:
+		panic(fmt.Sprintf("unhandled scenario type %q", s.scenarioType))
+	}
 }
 
 func TestPropertyScenarios(t *testing.T) {
 	for _, s := range propertyScenarios {
-		if s.scenarioType == "decode" {
-			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewPropertiesDecoder(), NewYamlEncoder(2, false, true, true)), s.description)
-		} else if s.scenarioType == "roundtrip" {
-			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewPropertiesDecoder(), NewPropertiesEncoder()), s.description)
-		} else {
-			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewYamlDecoder(), NewPropertiesEncoder()), s.description)
+		switch s.scenarioType {
+		case "":
+			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewYamlDecoder(ConfiguredYamlPreferences), NewPropertiesEncoder(true)), s.description)
+		case "decode":
+			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewPropertiesDecoder(), NewYamlEncoder(2, false, ConfiguredYamlPreferences)), s.description)
+		case "encode-wrapped":
+			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewYamlDecoder(ConfiguredYamlPreferences), NewPropertiesEncoder(false)), s.description)
+		case "roundtrip":
+			test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewPropertiesDecoder(), NewPropertiesEncoder(true)), s.description)
+
+		default:
+			panic(fmt.Sprintf("unhandled scenario type %q", s.scenarioType))
 		}
 	}
 	genericScenarios := make([]interface{}, len(propertyScenarios))
